const { IsoDateString } = require("../../Utils/Date/IsoDateString")
const { IsoDateString2UTC } = require("../../Utils/Date/UTC")

function IsNumberInRange(value, min, max) {
  value = parseInt(value)
  if(isNaN(value)) return false
  if(value < min) return false
  if(value > max) return false
  return true
}

function IsBeginEnd(beginHour, beginMinute, endHour, endMinute) {
  if(beginHour > endHour) return false
  if(beginHour < endHour) return true
  return beginMinute < endMinute
}

function IsTooLong(beginHour, beginMinute, endHour, endMinute, hours) {
  beginHour = parseInt(beginHour)
  beginMinute = parseInt(beginMinute)
  endHour = parseInt(endHour)
  endMinute = parseInt(endMinute)
  hours = parseInt(hours)
  return endHour*60 + endMinute > beginHour*60 + beginMinute + hours*60
}

function IsFuture(year, month, date, hour,  minute, timeZoneHourOffset) {
  const iso = IsoDateString(year, month, date, hour, minute, timeZoneHourOffset)
  const utc = IsoDateString2UTC(iso)
  const d = new Date()
  const todayUTC =
  Date.UTC(
    d.getUTCFullYear(),
    d.getUTCMonth(),
    d.getUTCDate(),
    d.getUTCHours(),
    d.getUTCMinutes()-1
  )
  return utc >= todayUTC
}

function IsTooFuture(year, month, date, hour,  minute, timeZoneHourOffset, days) {
  const iso = IsoDateString(year, month, date, hour, minute, timeZoneHourOffset)
  const utc = IsoDateString2UTC(iso)

  const d = new Date()
  const futureUTC =
  Date.UTC(
    d.getUTCFullYear(),
    d.getUTCMonth(),
    d.getUTCDate()+days,
    d.getUTCHours(),
    d.getUTCMinutes()-1
  )
  return utc > futureUTC
}

module.exports = {
  IsNumberInRange,
  IsBeginEnd,
  IsTooLong,
  IsFuture,
  IsTooFuture
}